@@ -67,7 +67,7 @@ class CoorsNorm(nn.Module):
     def forward(self, coors):
         norm = coors.norm(dim = -1, keepdim = True)
         normed_coors = coors / norm.clamp(min = self.eps)
-        return normed_coors
+        return normed_coors * self.scale
 
 class PreNorm(nn.Module):
     def __init__(self, dim, fn):
